# apileague-js

ApileagueJs - JavaScript client for apileague-js
API League is a Hub for World Class APIs.
This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.4
- Package version: 1.6.4
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/), please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install apileague-js --save
```

Finally, you need to build the module:

```shell
npm run build
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

To use the link you just defined in your project, switch to the directory you want to use your apileague-js from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

Finally, you need to build the module:

```shell
npm run build
```

#### git

If the library is hosted at a git repository, e.g.https://github.com/ddsky/api-league-clients/tree/master/javascript/
then install it via:

```shell
    npm install ddsky/api-league-clients/tree/master/javascript/ --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var ApileagueJs = require('apileague-js');

var defaultClient = ApileagueJs.ApiClient.instance;
// Configure API key authorization: apiKey
var apiKey = defaultClient.authentications['apiKey'];
apiKey.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//apiKey.apiKeyPrefix['api-key'] = "Token"
// Configure API key authorization: headerApiKey
var headerApiKey = defaultClient.authentications['headerApiKey'];
headerApiKey.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//headerApiKey.apiKeyPrefix['x-api-key'] = "Token"

var api = new ApileagueJs.ArtApi()
var url = "https://upload.wikimedia.org/wikipedia/commons/3/35/Basic_human_drawing.png"; // {String} The URL to the image.
var opts = {
  'width': 200, // {Number} The maximum width of the image (default 400, max. 500).
  'height': 200 // {Number} The maximum height of the image (default 400, max. 500).
};
var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.imageToAsciiArtByURLAPI(url, opts, callback);

```

## Documentation for API Endpoints

All URIs are relative to *https://api.apileague.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApileagueJs.ArtApi* | [**imageToAsciiArtByURLAPI**](docs/ArtApi.md#imageToAsciiArtByURLAPI) | **GET** /convert-image-to-ascii-txt | Image to Ascii Art by URL API
*ApileagueJs.ArtApi* | [**randomPoemAPI**](docs/ArtApi.md#randomPoemAPI) | **GET** /retrieve-random-poem | Random Poem API
*ApileagueJs.BooksApi* | [**findSimilarBooksAPI**](docs/BooksApi.md#findSimilarBooksAPI) | **GET** /list-similar-books | Find Similar Books API
*ApileagueJs.BooksApi* | [**searchBooksAPI**](docs/BooksApi.md#searchBooksAPI) | **GET** /search-books | Search Books API
*ApileagueJs.FoodApi* | [**computeNutritionAPI**](docs/FoodApi.md#computeNutritionAPI) | **GET** /compute-nutrition | Compute Nutrition API
*ApileagueJs.FoodApi* | [**retrieveRecipeInformationAPI**](docs/FoodApi.md#retrieveRecipeInformationAPI) | **GET** /retrieve-recipe | Retrieve Recipe Information API
*ApileagueJs.FoodApi* | [**searchDrinksAPI**](docs/FoodApi.md#searchDrinksAPI) | **GET** /search-drinks | Search Drinks API
*ApileagueJs.FoodApi* | [**searchRecipesAPI**](docs/FoodApi.md#searchRecipesAPI) | **GET** /search-recipes | Search Recipes API
*ApileagueJs.FoodApi* | [**searchRestaurantsAPI**](docs/FoodApi.md#searchRestaurantsAPI) | **GET** /search-restaurants | Search Restaurants API
*ApileagueJs.HumorApi* | [**generateNonsenseWordAPI**](docs/HumorApi.md#generateNonsenseWordAPI) | **GET** /generate-nonsense-word | Generate Nonsense Word API
*ApileagueJs.HumorApi* | [**randomJokeAPI**](docs/HumorApi.md#randomJokeAPI) | **GET** /retrieve-random-joke | Random Joke API
*ApileagueJs.HumorApi* | [**randomMemeAPI**](docs/HumorApi.md#randomMemeAPI) | **GET** /retrieve-random-meme | Random Meme API
*ApileagueJs.HumorApi* | [**searchGifsAPI**](docs/HumorApi.md#searchGifsAPI) | **GET** /search-gifs | Search Gifs API
*ApileagueJs.HumorApi* | [**searchJokesAPI**](docs/HumorApi.md#searchJokesAPI) | **GET** /search-jokes | Search Jokes API
*ApileagueJs.HumorApi* | [**searchMemesAPI**](docs/HumorApi.md#searchMemesAPI) | **GET** /search-memes | Search Memes API
*ApileagueJs.KnowledgeApi* | [**randomQuoteAPI**](docs/KnowledgeApi.md#randomQuoteAPI) | **GET** /retrieve-random-quote | Random Quote API
*ApileagueJs.KnowledgeApi* | [**randomRiddleAPI**](docs/KnowledgeApi.md#randomRiddleAPI) | **GET** /retrieve-random-riddle | Random Riddle API
*ApileagueJs.KnowledgeApi* | [**randomTriviaAPI**](docs/KnowledgeApi.md#randomTriviaAPI) | **GET** /retrieve-random-trivia | Random Trivia API
*ApileagueJs.MathApi* | [**convertUnitsAPI**](docs/MathApi.md#convertUnitsAPI) | **GET** /convert-units | Convert Units API
*ApileagueJs.MediaApi* | [**detectMainImageColorAPI**](docs/MediaApi.md#detectMainImageColorAPI) | **GET** /detect-color | Detect Main Image Color API
*ApileagueJs.MediaApi* | [**rescaleImageAPI**](docs/MediaApi.md#rescaleImageAPI) | **GET** /rescale-image | Rescale Image API
*ApileagueJs.MediaApi* | [**searchIconsAPI**](docs/MediaApi.md#searchIconsAPI) | **GET** /search-icons | Search Icons API
*ApileagueJs.MediaApi* | [**searchRoyaltyFreeImagesAPI**](docs/MediaApi.md#searchRoyaltyFreeImagesAPI) | **GET** /search-images | Search Royalty Free Images API
*ApileagueJs.MediaApi* | [**vectorSearchAPI**](docs/MediaApi.md#vectorSearchAPI) | **GET** /search-vectors | Vector Search API
*ApileagueJs.NewsApi* | [**extractNewsAPI**](docs/NewsApi.md#extractNewsAPI) | **GET** /extract-news | Extract News API
*ApileagueJs.NewsApi* | [**searchNewsAPI**](docs/NewsApi.md#searchNewsAPI) | **GET** /search-news | Search News API
*ApileagueJs.NewsApi* | [**topNewsAPI**](docs/NewsApi.md#topNewsAPI) | **GET** /retrieve-top-news | Top News API
*ApileagueJs.StorageApi* | [**readKeyValueFromStoreAPI**](docs/StorageApi.md#readKeyValueFromStoreAPI) | **GET** /read-key-value | Read Key Value from Store API
*ApileagueJs.StorageApi* | [**storeKeyValueGETAPI**](docs/StorageApi.md#storeKeyValueGETAPI) | **GET** /store-key-value | Store Key Value (GET) API
*ApileagueJs.TextApi* | [**correctSpellingAPI**](docs/TextApi.md#correctSpellingAPI) | **GET** /correct-spelling | Correct Spelling API
*ApileagueJs.TextApi* | [**detectGenderByNameAPI**](docs/TextApi.md#detectGenderByNameAPI) | **GET** /detect-gender | Detect Gender by Name API
*ApileagueJs.TextApi* | [**detectLanguageAPI**](docs/TextApi.md#detectLanguageAPI) | **GET** /detect-language | Detect Language API
*ApileagueJs.TextApi* | [**detectSentimentAPI**](docs/TextApi.md#detectSentimentAPI) | **GET** /detect-sentiment | Detect Sentiment API
*ApileagueJs.TextApi* | [**extractDatesAPI**](docs/TextApi.md#extractDatesAPI) | **GET** /extract-dates | Extract Dates API
*ApileagueJs.TextApi* | [**extractEntitiesAPI**](docs/TextApi.md#extractEntitiesAPI) | **GET** /extract-entities | Extract Entities API
*ApileagueJs.TextApi* | [**listWordSynonymsAPI**](docs/TextApi.md#listWordSynonymsAPI) | **GET** /list-synonyms | List Word Synonyms API
*ApileagueJs.TextApi* | [**pluralizeWordAPI**](docs/TextApi.md#pluralizeWordAPI) | **GET** /pluralize-word | Pluralize Word API
*ApileagueJs.TextApi* | [**scoreReadabilityAPI**](docs/TextApi.md#scoreReadabilityAPI) | **GET** /score-readability | Score Readability API
*ApileagueJs.TextApi* | [**scoreTextAPI**](docs/TextApi.md#scoreTextAPI) | **GET** /score-text | Score Text API
*ApileagueJs.TextApi* | [**singularizeWordAPI**](docs/TextApi.md#singularizeWordAPI) | **GET** /singularize-word | Singularize Word API
*ApileagueJs.TextApi* | [**stemTextAPI**](docs/TextApi.md#stemTextAPI) | **GET** /stem-text | Stem Text API
*ApileagueJs.TextApi* | [**tagPartOfSpeechAPI**](docs/TextApi.md#tagPartOfSpeechAPI) | **GET** /tag-pos | Tag Part of Speech API
*ApileagueJs.WebApi* | [**extractAuthorsAPI**](docs/WebApi.md#extractAuthorsAPI) | **GET** /extract-authors | Extract Authors API
*ApileagueJs.WebApi* | [**extractContentFromAWebPageAPI**](docs/WebApi.md#extractContentFromAWebPageAPI) | **GET** /extract-content | Extract Content from a Web Page API
*ApileagueJs.WebApi* | [**extractPublishDateAPI**](docs/WebApi.md#extractPublishDateAPI) | **GET** /extract-publish-date | Extract Publish Date API
*ApileagueJs.WebApi* | [**retrievePageRankAPI**](docs/WebApi.md#retrievePageRankAPI) | **GET** /retrieve-page-rank | Retrieve Page Rank API
*ApileagueJs.WebApi* | [**searchWebAPI**](docs/WebApi.md#searchWebAPI) | **GET** /search-web | Search Web API
*ApileagueJs.WebApi* | [**verifyEmailAddressAPI**](docs/WebApi.md#verifyEmailAddressAPI) | **GET** /verify-email | Verify Email Address API


## Documentation for Models

 - [ApileagueJs.ComputeNutritionAPI200Response](docs/ComputeNutritionAPI200Response.md)
 - [ApileagueJs.ComputeNutritionAPI200ResponseIngredientBreakdownInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInner.md)
 - [ApileagueJs.ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner.md)
 - [ApileagueJs.ConvertUnitsAPI200Response](docs/ConvertUnitsAPI200Response.md)
 - [ApileagueJs.CorrectSpellingAPI200Response](docs/CorrectSpellingAPI200Response.md)
 - [ApileagueJs.DetectGenderByNameAPI200Response](docs/DetectGenderByNameAPI200Response.md)
 - [ApileagueJs.DetectLanguageAPI200ResponseInner](docs/DetectLanguageAPI200ResponseInner.md)
 - [ApileagueJs.DetectMainImageColorAPI200ResponseInner](docs/DetectMainImageColorAPI200ResponseInner.md)
 - [ApileagueJs.DetectSentimentAPI200Response](docs/DetectSentimentAPI200Response.md)
 - [ApileagueJs.DetectSentimentAPI200ResponseDocument](docs/DetectSentimentAPI200ResponseDocument.md)
 - [ApileagueJs.DetectSentimentAPI200ResponseSentencesInner](docs/DetectSentimentAPI200ResponseSentencesInner.md)
 - [ApileagueJs.ExtractAuthorsAPI200Response](docs/ExtractAuthorsAPI200Response.md)
 - [ApileagueJs.ExtractAuthorsAPI200ResponseAuthorsInner](docs/ExtractAuthorsAPI200ResponseAuthorsInner.md)
 - [ApileagueJs.ExtractContentFromAWebPageAPI200Response](docs/ExtractContentFromAWebPageAPI200Response.md)
 - [ApileagueJs.ExtractDatesAPI200Response](docs/ExtractDatesAPI200Response.md)
 - [ApileagueJs.ExtractDatesAPI200ResponseDatesInner](docs/ExtractDatesAPI200ResponseDatesInner.md)
 - [ApileagueJs.ExtractEntitiesAPI200Response](docs/ExtractEntitiesAPI200Response.md)
 - [ApileagueJs.ExtractEntitiesAPI200ResponseEntitiesInner](docs/ExtractEntitiesAPI200ResponseEntitiesInner.md)
 - [ApileagueJs.ExtractNewsAPI200Response](docs/ExtractNewsAPI200Response.md)
 - [ApileagueJs.ExtractNewsAPI200ResponseImagesInner](docs/ExtractNewsAPI200ResponseImagesInner.md)
 - [ApileagueJs.ExtractNewsAPI200ResponseVideosInner](docs/ExtractNewsAPI200ResponseVideosInner.md)
 - [ApileagueJs.ExtractPublishDateAPI200Response](docs/ExtractPublishDateAPI200Response.md)
 - [ApileagueJs.FindSimilarBooksAPI200Response](docs/FindSimilarBooksAPI200Response.md)
 - [ApileagueJs.GenerateNonsenseWordAPI200Response](docs/GenerateNonsenseWordAPI200Response.md)
 - [ApileagueJs.ListWordSynonymsAPI200Response](docs/ListWordSynonymsAPI200Response.md)
 - [ApileagueJs.PluralizeWordAPI200Response](docs/PluralizeWordAPI200Response.md)
 - [ApileagueJs.RandomMemeAPI200Response](docs/RandomMemeAPI200Response.md)
 - [ApileagueJs.RandomPoemAPI200Response](docs/RandomPoemAPI200Response.md)
 - [ApileagueJs.RandomQuoteAPI200Response](docs/RandomQuoteAPI200Response.md)
 - [ApileagueJs.RandomRiddleAPI200Response](docs/RandomRiddleAPI200Response.md)
 - [ApileagueJs.RandomTriviaAPI200Response](docs/RandomTriviaAPI200Response.md)
 - [ApileagueJs.ReadKeyValueFromStoreAPI200Response](docs/ReadKeyValueFromStoreAPI200Response.md)
 - [ApileagueJs.RetrievePageRankAPI200Response](docs/RetrievePageRankAPI200Response.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200Response](docs/RetrieveRecipeInformationAPI200Response.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseCredits](docs/RetrieveRecipeInformationAPI200ResponseCredits.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseDietaryProperties](docs/RetrieveRecipeInformationAPI200ResponseDietaryProperties.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseIngredientsInner](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInner.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseInstructionsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInner.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseNutrition](docs/RetrieveRecipeInformationAPI200ResponseNutrition.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner](docs/RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseScores](docs/RetrieveRecipeInformationAPI200ResponseScores.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseTaste](docs/RetrieveRecipeInformationAPI200ResponseTaste.md)
 - [ApileagueJs.RetrieveRecipeInformationAPI200ResponseTimes](docs/RetrieveRecipeInformationAPI200ResponseTimes.md)
 - [ApileagueJs.ScoreReadabilityAPI200Response](docs/ScoreReadabilityAPI200Response.md)
 - [ApileagueJs.ScoreTextAPI200Response](docs/ScoreTextAPI200Response.md)
 - [ApileagueJs.ScoreTextAPI200ResponseInterestingness](docs/ScoreTextAPI200ResponseInterestingness.md)
 - [ApileagueJs.ScoreTextAPI200ResponseInterestingnessSubscores](docs/ScoreTextAPI200ResponseInterestingnessSubscores.md)
 - [ApileagueJs.ScoreTextAPI200ResponseReadability](docs/ScoreTextAPI200ResponseReadability.md)
 - [ApileagueJs.ScoreTextAPI200ResponseReadabilityMainscores](docs/ScoreTextAPI200ResponseReadabilityMainscores.md)
 - [ApileagueJs.ScoreTextAPI200ResponseReadabilitySubscores](docs/ScoreTextAPI200ResponseReadabilitySubscores.md)
 - [ApileagueJs.ScoreTextAPI200ResponseSkimmability](docs/ScoreTextAPI200ResponseSkimmability.md)
 - [ApileagueJs.ScoreTextAPI200ResponseSkimmabilityMainscores](docs/ScoreTextAPI200ResponseSkimmabilityMainscores.md)
 - [ApileagueJs.ScoreTextAPI200ResponseSkimmabilitySubscores](docs/ScoreTextAPI200ResponseSkimmabilitySubscores.md)
 - [ApileagueJs.ScoreTextAPI200ResponseStyle](docs/ScoreTextAPI200ResponseStyle.md)
 - [ApileagueJs.ScoreTextAPI200ResponseStyleSubscores](docs/ScoreTextAPI200ResponseStyleSubscores.md)
 - [ApileagueJs.SearchBooksAPI200Response](docs/SearchBooksAPI200Response.md)
 - [ApileagueJs.SearchBooksAPI200ResponseBooksInnerInner](docs/SearchBooksAPI200ResponseBooksInnerInner.md)
 - [ApileagueJs.SearchDrinksAPI200Response](docs/SearchDrinksAPI200Response.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInner](docs/SearchDrinksAPI200ResponseDrinksInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerCredits](docs/SearchDrinksAPI200ResponseDrinksInnerCredits.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerInstructionsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutrition](docs/SearchDrinksAPI200ResponseDrinksInnerNutrition.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner.md)
 - [ApileagueJs.SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing.md)
 - [ApileagueJs.SearchGifsAPI200Response](docs/SearchGifsAPI200Response.md)
 - [ApileagueJs.SearchGifsAPI200ResponseImagesInner](docs/SearchGifsAPI200ResponseImagesInner.md)
 - [ApileagueJs.SearchIconsAPI200Response](docs/SearchIconsAPI200Response.md)
 - [ApileagueJs.SearchJokesAPI200Response](docs/SearchJokesAPI200Response.md)
 - [ApileagueJs.SearchJokesAPI200ResponseJokesInner](docs/SearchJokesAPI200ResponseJokesInner.md)
 - [ApileagueJs.SearchMemesAPI200Response](docs/SearchMemesAPI200Response.md)
 - [ApileagueJs.SearchMemesAPI200ResponseMemesInner](docs/SearchMemesAPI200ResponseMemesInner.md)
 - [ApileagueJs.SearchNewsAPI200Response](docs/SearchNewsAPI200Response.md)
 - [ApileagueJs.SearchNewsAPI200ResponseNewsInner](docs/SearchNewsAPI200ResponseNewsInner.md)
 - [ApileagueJs.SearchRecipesAPI200Response](docs/SearchRecipesAPI200Response.md)
 - [ApileagueJs.SearchRecipesAPI200ResponseRecipesInner](docs/SearchRecipesAPI200ResponseRecipesInner.md)
 - [ApileagueJs.SearchRecipesAPI200ResponseRecipesInnerNutrition](docs/SearchRecipesAPI200ResponseRecipesInnerNutrition.md)
 - [ApileagueJs.SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner](docs/SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner.md)
 - [ApileagueJs.SearchRestaurantsAPI200Response](docs/SearchRestaurantsAPI200Response.md)
 - [ApileagueJs.SearchRestaurantsAPI200ResponseRestaurantsInner](docs/SearchRestaurantsAPI200ResponseRestaurantsInner.md)
 - [ApileagueJs.SearchRestaurantsAPI200ResponseRestaurantsInnerAddress](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerAddress.md)
 - [ApileagueJs.SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours.md)
 - [ApileagueJs.SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [ApileagueJs.SearchRoyaltyFreeImagesAPI200Response](docs/SearchRoyaltyFreeImagesAPI200Response.md)
 - [ApileagueJs.SearchRoyaltyFreeImagesAPI200ResponseImagesInner](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInner.md)
 - [ApileagueJs.SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense.md)
 - [ApileagueJs.SearchWebAPI200Response](docs/SearchWebAPI200Response.md)
 - [ApileagueJs.SearchWebAPI200ResponseResultsInner](docs/SearchWebAPI200ResponseResultsInner.md)
 - [ApileagueJs.SingularizeWordAPI200Response](docs/SingularizeWordAPI200Response.md)
 - [ApileagueJs.StemTextAPI200Response](docs/StemTextAPI200Response.md)
 - [ApileagueJs.StoreKeyValueGETAPI200Response](docs/StoreKeyValueGETAPI200Response.md)
 - [ApileagueJs.TagPartOfSpeechAPI200Response](docs/TagPartOfSpeechAPI200Response.md)
 - [ApileagueJs.TopNewsAPI200Response](docs/TopNewsAPI200Response.md)
 - [ApileagueJs.TopNewsAPI200ResponseTopNewsInner](docs/TopNewsAPI200ResponseTopNewsInner.md)
 - [ApileagueJs.TopNewsAPI200ResponseTopNewsInnerNewsInner](docs/TopNewsAPI200ResponseTopNewsInnerNewsInner.md)
 - [ApileagueJs.VectorSearchAPI200Response](docs/VectorSearchAPI200Response.md)
 - [ApileagueJs.VectorSearchAPI200ResponseVectorsInner](docs/VectorSearchAPI200ResponseVectorsInner.md)
 - [ApileagueJs.VerifyEmailAddressAPI200Response](docs/VerifyEmailAddressAPI200Response.md)


## Documentation for Authorization


Authentication schemes defined for the API:
### apiKey


- **Type**: API key
- **API key parameter name**: api-key
- **Location**: URL query string

### headerApiKey


- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

